#!/bin/bash
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package			: dvd95
# homepage			: http://dvd95.sourceforge.net/
# source location	: http://mesh.dl.sourceforge.net/sourceforge/dvd95/dvd95-1.5p3.tar.gz
# dependency        : DVDAuthor,libdvdread,libdvdcss,mencoder,mplayer

softname='dvd95'
softversion='1.6p0'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://mesh.dl.sourceforge.net/sourceforge/$softname/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
     |-----handy-ruler------------------------------------------------------|
dvd95: DVD95 - Backup your DVD
dvd95:
dvd95: DVD95 is a GNOME application to convert DVD9 to DVD5. 
dvd95: DVD95 is free and open-source software licensed 
dvd95: under the terms of the GNU GPL v2.
dvd95:
dvd95:
dvd95:
dvd95:
dvd95: 
dvd95:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code 
cd $buildir
tar xzvf $srcpkg
cd $src	

# building
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

sed -i -e 's|CFLAGS="-Wall -O3"|CFLAGS=${CFLAGS:-"-Wall -O3"}|g' configure
    
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# fix icon
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/dvd95/dvd9548.png $softname.png

# make .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Dvd95
Comment=DVD utility
Exec=dvd95
Icon=dvd95
Categories=Application;AudioVideo;
Terminal=false
Type=Application
Encoding=UTF-8
EOF

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion
	
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp dvdread.patch $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "alsa-lib,atk,audiofile,avahi,cairo,cxxlibs|gcc-g++,dbus,dbus-glib,\
esound,expat,fontconfig,freetype,gcc,gconf,glib2,gnome-keyring,gnome-vfs,gtk+2,\
libICE,libSM,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libart_lgpl,libbonobo,libbonoboui,\
libdvdread,libgnome,libgnomecanvas,libgnomeui,libpng,libxcb,libxml2,mpeg2dec,openssl,\
orbit2,pango,pixman,popt,util-linux-ng,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/dvd95/source/build-dvd95.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
